==> jc-1.4.0.tar.gz: javax/security/auth/callback/TextInputCallback.h <==
// public class javax.security.auth.callback.TextInputCallback

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 89cc839ce5e99ecf javax_security_auth_callback_TextInputCallback

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_auth_callback_TextInputCallback_H_
#define _JC_javax_security_auth_callback_TextInputCallback_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_auth_callback_TextInputCallback$sub_refs	_jc_javax_security_auth_callback_TextInputCallback$sub_refs;
typedef struct _jc_javax_security_auth_callback_TextInputCallback$sub_nonrefs	_jc_javax_security_auth_callback_TextInputCallback$sub_nonrefs;
typedef struct _jc_javax_security_auth_callback_TextInputCallback$refs	_jc_javax_security_auth_callback_TextInputCallback$refs;
typedef struct _jc_javax_security_auth_callback_TextInputCallback$nonrefs	_jc_javax_security_auth_callback_TextInputCallback$nonrefs;
typedef struct _jc_javax_security_auth_callback_TextInputCallback$object	_jc_javax_security_auth_callback_TextInputCallback$object;

typedef const struct _jc_javax_security_auth_callback_TextInputCallback$vmethods	_jc_javax_security_auth_callback_TextInputCallback$vmethods;
typedef const struct _jc_javax_security_auth_callback_TextInputCallback$vtable	_jc_javax_security_auth_callback_TextInputCallback$vtable;
typedef const struct _jc_javax_security_auth_callback_TextInputCallback$vtype	_jc_javax_security_auth_callback_TextInputCallback$vtype;

// Constructors
extern void _jc_javax_security_auth_callback_TextInputCallback$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_security_auth_callback_TextInputCallback$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_callback_TextInputCallback$method$getDefaultText$8a9db0033da00041(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *);
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_callback_TextInputCallback$method$getPrompt$ad6bd756fb4800ba(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *);
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_callback_TextInputCallback$method$getText$e563ff505469c39b(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *);
extern void _jc_javax_security_auth_callback_TextInputCallback$method$setDefaultText$142f1a0a1bc26099(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_security_auth_callback_TextInputCallback$method$setPrompt$7b347b9990ff5882(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_security_auth_callback_TextInputCallback$method$setText$2774cf9ec78ebefc(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_callback_TextInputCallback$method_info$getDefaultText$8a9db0033da00041;
extern _jc_method _jc_javax_security_auth_callback_TextInputCallback$method_info$getPrompt$ad6bd756fb4800ba;
extern _jc_method _jc_javax_security_auth_callback_TextInputCallback$method_info$getText$e563ff505469c39b;
extern _jc_method _jc_javax_security_auth_callback_TextInputCallback$method_info$setDefaultText$142f1a0a1bc26099;
extern _jc_method _jc_javax_security_auth_callback_TextInputCallback$method_info$setPrompt$7b347b9990ff5882;
extern _jc_method _jc_javax_security_auth_callback_TextInputCallback$method_info$setText$2774cf9ec78ebefc;

// Virtual methods structure
struct _jc_javax_security_auth_callback_TextInputCallback$vmethods {
	struct _jc_java_lang_String$object	*(*getDefaultText$8a9db0033da00041)(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *);
	struct _jc_java_lang_String$object	*(*getPrompt$ad6bd756fb4800ba)(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *);
	struct _jc_java_lang_String$object	*(*getText$e563ff505469c39b)(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *);
	void	(*setDefaultText$142f1a0a1bc26099)(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *, struct _jc_java_lang_String$object *);
	void	(*setPrompt$7b347b9990ff5882)(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *, struct _jc_java_lang_String$object *);
	void	(*setText$2774cf9ec78ebefc)(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_javax_security_auth_callback_TextInputCallback$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_callback_TextInputCallback$vmethods	javax_security_auth_callback_TextInputCallback;
};

// Vtype
struct _jc_javax_security_auth_callback_TextInputCallback$vtype {
	_jc_type			type;
	_jc_javax_security_auth_callback_TextInputCallback$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_callback_TextInputCallback$sub_refs {
	struct _jc_java_lang_String$object	*prompt;
	struct _jc_java_lang_String$object	*defaultText;
	struct _jc_java_lang_String$object	*inputText;
};

// Reference instance fields (object)
struct _jc_javax_security_auth_callback_TextInputCallback$refs {
    _jc_javax_security_auth_callback_TextInputCallback$sub_refs	javax_security_auth_callback_TextInputCallback;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_callback_TextInputCallback$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_callback_TextInputCallback$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_callback_TextInputCallback$sub_nonrefs	javax_security_auth_callback_TextInputCallback;
};

// Object instance structure
struct _jc_javax_security_auth_callback_TextInputCallback$object {
	_jc_javax_security_auth_callback_TextInputCallback$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_callback_TextInputCallback$vtype	*vtype;
	_jc_javax_security_auth_callback_TextInputCallback$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_callback_TextInputCallback$vtype _jc_javax_security_auth_callback_TextInputCallback$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_callback_TextInputCallback, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_callback_TextInputCallback$class_object;

#endif	/* _JC_javax_security_auth_callback_TextInputCallback_H_ */

==> jc-1.4.6.tar.gz: javax/security/auth/callback/TextInputCallback.h <==
// public class javax.security.auth.callback.TextInputCallback

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 89cc839ce5e99ecf javax_security_auth_callback_TextInputCallback

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_auth_callback_TextInputCallback_H_
#define _JC_javax_security_auth_callback_TextInputCallback_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_auth_callback_TextInputCallback$sub_refs	_jc_javax_security_auth_callback_TextInputCallback$sub_refs;
typedef struct _jc_javax_security_auth_callback_TextInputCallback$sub_nonrefs	_jc_javax_security_auth_callback_TextInputCallback$sub_nonrefs;
typedef struct _jc_javax_security_auth_callback_TextInputCallback$refs	_jc_javax_security_auth_callback_TextInputCallback$refs;
typedef struct _jc_javax_security_auth_callback_TextInputCallback$nonrefs	_jc_javax_security_auth_callback_TextInputCallback$nonrefs;
typedef struct _jc_javax_security_auth_callback_TextInputCallback$object	_jc_javax_security_auth_callback_TextInputCallback$object;

typedef const struct _jc_javax_security_auth_callback_TextInputCallback$vmethods	_jc_javax_security_auth_callback_TextInputCallback$vmethods;
typedef const struct _jc_javax_security_auth_callback_TextInputCallback$vtable	_jc_javax_security_auth_callback_TextInputCallback$vtable;
typedef const struct _jc_javax_security_auth_callback_TextInputCallback$vtype	_jc_javax_security_auth_callback_TextInputCallback$vtype;

// Constructors
extern void _jc_javax_security_auth_callback_TextInputCallback$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_auth_callback_TextInputCallback$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_callback_TextInputCallback$method$getDefaultText$8a9db0033da00041(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_callback_TextInputCallback$method$getPrompt$ad6bd756fb4800ba(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_callback_TextInputCallback$method$getText$e563ff505469c39b(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_auth_callback_TextInputCallback$method$setDefaultText$142f1a0a1bc26099(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_auth_callback_TextInputCallback$method$setPrompt$7b347b9990ff5882(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_auth_callback_TextInputCallback$method$setText$2774cf9ec78ebefc(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_callback_TextInputCallback$method_info$getDefaultText$8a9db0033da00041;
extern _jc_method _jc_javax_security_auth_callback_TextInputCallback$method_info$getPrompt$ad6bd756fb4800ba;
extern _jc_method _jc_javax_security_auth_callback_TextInputCallback$method_info$getText$e563ff505469c39b;
extern _jc_method _jc_javax_security_auth_callback_TextInputCallback$method_info$setDefaultText$142f1a0a1bc26099;
extern _jc_method _jc_javax_security_auth_callback_TextInputCallback$method_info$setPrompt$7b347b9990ff5882;
extern _jc_method _jc_javax_security_auth_callback_TextInputCallback$method_info$setText$2774cf9ec78ebefc;

// Virtual methods structure
struct _jc_javax_security_auth_callback_TextInputCallback$vmethods {
	struct _jc_java_lang_String$object	*(*getDefaultText$8a9db0033da00041)(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getPrompt$ad6bd756fb4800ba)(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getText$e563ff505469c39b)(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *) _JC_JCNI_ATTR;
	void	(*setDefaultText$142f1a0a1bc26099)(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*setPrompt$7b347b9990ff5882)(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*setText$2774cf9ec78ebefc)(_jc_env *, struct _jc_javax_security_auth_callback_TextInputCallback$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_security_auth_callback_TextInputCallback$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_callback_TextInputCallback$vmethods	javax_security_auth_callback_TextInputCallback;
};

// Vtype
struct _jc_javax_security_auth_callback_TextInputCallback$vtype {
	_jc_type			type;
	_jc_javax_security_auth_callback_TextInputCallback$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_callback_TextInputCallback$sub_refs {
	struct _jc_java_lang_String$object	*prompt;
	struct _jc_java_lang_String$object	*defaultText;
	struct _jc_java_lang_String$object	*inputText;
};

// Reference instance fields (object)
struct _jc_javax_security_auth_callback_TextInputCallback$refs {
    _jc_javax_security_auth_callback_TextInputCallback$sub_refs	javax_security_auth_callback_TextInputCallback;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_callback_TextInputCallback$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_callback_TextInputCallback$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_callback_TextInputCallback$sub_nonrefs	javax_security_auth_callback_TextInputCallback;
};

// Object instance structure
struct _jc_javax_security_auth_callback_TextInputCallback$object {
	_jc_javax_security_auth_callback_TextInputCallback$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_callback_TextInputCallback$vtype	*vtype;
	_jc_javax_security_auth_callback_TextInputCallback$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_callback_TextInputCallback$vtype _jc_javax_security_auth_callback_TextInputCallback$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_callback_TextInputCallback, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_callback_TextInputCallback$class_object;

#endif	/* _JC_javax_security_auth_callback_TextInputCallback_H_ */
